@@ -31,12 +31,12 @@
 #include <stdlib.h>
 
 #include <gdk/gdkkeysyms.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
-#include <libmissioncontrol/mission-control.h>
 #include <telepathy-glib/util.h>
 
+#include <libempathy/empathy-account-manager.h>
 #include <libempathy/empathy-log-manager.h>
 #include <libempathy/empathy-contact-list.h>
 #include <libempathy/empathy-utils.h>
@@ -48,6 +48,8 @@
 #include "empathy-contact-list-store.h"
 #include "empathy-contact-list-view.h"
 #include "empathy-contact-menu.h"
+#include "empathy-theme-manager.h"
+#include "empathy-smiley-manager.h"
 #include "empathy-ui-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
@@ -69,7 +71,7 @@ typedef struct {
 	EmpathyContact    *remote_contact;
 
 	EmpathyLogManager *log_manager;
-	MissionControl    *mc;
+	EmpathyAccountManager *account_manager;
 	GSList            *sent_messages;
 	gint               sent_messages_index;
 	GList             *compositors;
@@ -77,7 +79,6 @@ typedef struct {
 	guint              composing_stop_timeout_id;
 	guint              block_events_timeout_id;
 	TpHandleType       handle_type;
-	gpointer           token;
 	gint               contacts_width;
 	gboolean           has_input_vscroll;
 
@@ -165,24 +166,24 @@ chat_set_property (GObject      *object,
 }
 
 static void
-chat_status_changed_cb (MissionControl           *mc,
-			TpConnectionStatus        status,
-			McPresence                presence,
-			TpConnectionStatusReason  reason,
-			const gchar              *unique_name,
-			EmpathyChat              *chat)
+chat_connection_changed_cb (EmpathyAccountManager *manager,
+			    McAccount *account,
+			    TpConnectionStatusReason reason,
+			    TpConnectionStatus current,
+			    TpConnectionStatus previous,
+			    EmpathyChat *chat)
 {
 	EmpathyChatPriv *priv = GET_PRIV (chat);
-	McAccount       *account;
 
-	account = mc_account_lookup (unique_name);
-
-	if (status == TP_CONNECTION_STATUS_CONNECTED && !priv->tp_chat &&
+	if (current == TP_CONNECTION_STATUS_CONNECTED && !priv->tp_chat &&
 	    empathy_account_equal (account, priv->account) &&
 	    priv->handle_type != TP_HANDLE_TYPE_NONE) {
 		TpConnection *connection;
+		MissionControl *mc;
 
 		DEBUG ("Account reconnected, request a new Text channel");
+
+		mc = empathy_mission_control_new ();
 		connection = mission_control_get_tpconnection (mc, account, NULL);
 		tp_connection_run_until_ready (connection, FALSE, NULL, NULL);
 		empathy_connection_request_channel (connection, -1,
@@ -191,9 +192,8 @@ chat_status_changed_cb (MissionControl           *mc,
 						    priv->id, TRUE,
 						    NULL, NULL, NULL, NULL);
 		g_object_unref (connection);
+		g_object_unref (mc);
 	}
-
-	g_object_unref (account);
 }
 
 static void
@@ -867,19 +867,18 @@ chat_input_realize_cb (GtkWidget   *widget,
 }
 
 static void
-chat_insert_smiley_activate_cb (GtkWidget   *menuitem,
-				EmpathyChat *chat)
+chat_insert_smiley_activate_cb (EmpathySmileyManager *manager,
+				EmpathySmiley        *smiley,
+				gpointer              user_data)
 {
+	EmpathyChat   *chat = EMPATHY_CHAT (user_data);
 	GtkTextBuffer *buffer;
 	GtkTextIter    iter;
-	const gchar   *smiley;
-
-	smiley = g_object_get_data (G_OBJECT (menuitem), "smiley_text");
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (chat->input_text_view));
 
 	gtk_text_buffer_get_end_iter (buffer, &iter);
-	gtk_text_buffer_insert (buffer, &iter, smiley, -1);
+	gtk_text_buffer_insert (buffer, &iter, smiley->str, -1);
 
 	gtk_text_buffer_get_end_iter (buffer, &iter);
 	gtk_text_buffer_insert (buffer, &iter, " ", -1);
@@ -941,17 +940,18 @@ chat_input_populate_popup_cb (GtkTextView *view,
 			      GtkMenu     *menu,
 			      EmpathyChat *chat)
 {
-	EmpathyChatPriv  *priv;
-	GtkTextBuffer   *buffer;
-	GtkTextTagTable *table;
-	GtkTextTag      *tag;
-	gint             x, y;
-	GtkTextIter      iter, start, end;
-	GtkWidget       *item;
-	gchar           *str = NULL;
-	EmpathyChatSpell *chat_spell;
-	GtkWidget       *smiley_menu;
-	GtkWidget       *image;
+	EmpathyChatPriv      *priv;
+	GtkTextBuffer        *buffer;
+	GtkTextTagTable      *table;
+	GtkTextTag           *tag;
+	gint                  x, y;
+	GtkTextIter           iter, start, end;
+	GtkWidget            *item;
+	gchar                *str = NULL;
+	EmpathyChatSpell      *chat_spell;
+	EmpathySmileyManager *smiley_manager;
+	GtkWidget            *smiley_menu;
+	GtkWidget            *image;
 
 	priv = GET_PRIV (chat);
 	buffer = gtk_text_view_get_buffer (view);
@@ -968,10 +968,12 @@ chat_input_populate_popup_cb (GtkTextView *view,
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), item);
 	gtk_widget_show (item);
 
-	smiley_menu = empathy_chat_view_get_smiley_menu (
-		G_CALLBACK (chat_insert_smiley_activate_cb),
-		chat);
+	smiley_manager = empathy_smiley_manager_new ();
+	smiley_menu = empathy_smiley_menu_new (smiley_manager,
+					       chat_insert_smiley_activate_cb,
+					       chat);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), smiley_menu);
+	g_object_unref (smiley_manager);
 
 	/* Add the Send menu item. */
 	gtk_text_buffer_get_bounds (buffer, &start, &end);
@@ -1265,8 +1267,8 @@ chat_create_ui (EmpathyChat *chat)
 	g_free (filename);
 	g_object_unref (glade);
 
-	/* Add message GtkTextView. */
-	chat->view = empathy_chat_view_new ();
+	/* Add message view. */
+	chat->view = empathy_theme_manager_create_view (empathy_theme_manager_get ());
 	g_signal_connect (chat->view, "focus_in_event",
 			  G_CALLBACK (chat_text_view_focus_in_event_cb),
 			  chat);
@@ -1390,8 +1392,10 @@ chat_finalize (GObject *object)
 
 	chat_composing_remove_timeout (chat);
 
-	empathy_disconnect_account_status_changed (priv->token);
-	g_object_unref (priv->mc);
+	g_signal_handlers_disconnect_by_func (priv->account_manager,
+					      chat_connection_changed_cb, object);
+
+	g_object_unref (priv->account_manager);
 	g_object_unref (priv->log_manager);
 
 	if (priv->tp_chat) {
@@ -1526,11 +1530,12 @@ empathy_chat_init (EmpathyChat *chat)
 	priv->contacts_width = -1;
 	priv->sent_messages = NULL;
 	priv->sent_messages_index = -1;
-	priv->mc = empathy_mission_control_new ();
+	priv->account_manager = empathy_account_manager_dup_singleton ();
 
-	priv->token = empathy_connect_to_account_status_changed (priv->mc,
-						   G_CALLBACK (chat_status_changed_cb),
-						   chat, NULL);
+	g_signal_connect (priv->account_manager,
+			  "account-connection-changed",
+			  G_CALLBACK (chat_connection_changed_cb),
+			  chat);
 
 	/* Block events for some time to avoid having "has come online" or
 	 * "joined" messages. */
@@ -1739,7 +1744,7 @@ empathy_chat_cut (EmpathyChat *chat)
 	g_return_if_fail (EMPATHY_IS_CHAT (chat));
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (chat->input_text_view));
-	if (gtk_text_buffer_get_selection_bounds (buffer, NULL, NULL)) {
+	if (gtk_text_buffer_get_has_selection (buffer)) {
 		GtkClipboard *clipboard;
 
 		clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
@@ -1755,13 +1760,13 @@ empathy_chat_copy (EmpathyChat *chat)
 
 	g_return_if_fail (EMPATHY_IS_CHAT (chat));
 
-	if (empathy_chat_view_get_selection_bounds (chat->view, NULL, NULL)) {
+	if (empathy_chat_view_get_has_selection (chat->view)) {
 		empathy_chat_view_copy_clipboard (chat->view);
 		return;
 	}
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (chat->input_text_view));
-	if (gtk_text_buffer_get_selection_bounds (buffer, NULL, NULL)) {
+	if (gtk_text_buffer_get_has_selection (buffer)) {
 		GtkClipboard *clipboard;
 
 		clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
