@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,7 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <libmissioncontrol/mission-control.h>
 
@@ -53,7 +53,7 @@ contact_dialogs_find (GtkDialog      *dialog,
 	contact_widget = g_object_get_data (G_OBJECT (dialog), "contact_widget");
 	this_contact = empathy_contact_widget_get_contact (contact_widget);
 
-	return !empathy_contact_equal (contact, this_contact);
+	return contact != this_contact;
 }
 
 /*
@@ -93,6 +93,7 @@ empathy_subscription_dialog_show (EmpathyContact *contact,
 	GtkWidget *hbox_subscription;
 	GtkWidget *contact_widget;
 	GList     *l;
+	gchar     *filename;
 
 	g_return_if_fail (EMPATHY_IS_CONTACT (contact));
 
@@ -104,12 +105,15 @@ empathy_subscription_dialog_show (EmpathyContact *contact,
 		return;
 	}
 
-	empathy_glade_get_file_simple ("empathy-contact-dialogs.glade",
+	filename = empathy_file_lookup ("empathy-contact-dialogs.glade",
+					"libempathy-gtk");
+	empathy_glade_get_file_simple (filename,
 				      "subscription_request_dialog",
 				      NULL,
 				      "subscription_request_dialog", &dialog,
 				      "hbox_subscription", &hbox_subscription,
 				      NULL);
+	g_free (filename);
 
 	contact_widget = empathy_contact_widget_new (contact,
 						     EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
@@ -188,6 +192,8 @@ empathy_contact_information_dialog_show (EmpathyContact *contact,
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
 				      button,
 				      GTK_RESPONSE_CLOSE);
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_window_set_default (GTK_WINDOW (dialog), button);
 	gtk_widget_show (button);
 
 	/* Contact info widget */
@@ -233,31 +239,14 @@ static gboolean
 can_add_contact_to_account (McAccount *account,
 			    gpointer   user_data)
 {
-	MissionControl            *mc;
-	TelepathyConnectionStatus  status;
-	McProfile                 *profile;
-	const gchar               *protocol_name;
+	EmpathyContactManager *mgr;
+	gboolean               result;
 
-	mc = empathy_mission_control_new ();
-	status = mission_control_get_connection_status (mc, account, NULL);
-	g_object_unref (mc);
-	if (status != TP_CONN_STATUS_CONNECTED) {
-		/* Account is disconnected */
-		return FALSE;
-	}
+	mgr = empathy_contact_manager_new ();
+	result = empathy_contact_manager_can_add (mgr, account);
+	g_object_unref (mgr);
 
-	profile = mc_account_get_profile (account);
-	protocol_name = mc_profile_get_protocol_name (profile);
-	if (strcmp (protocol_name, "local-xmpp") == 0) {
-		/* We can't add accounts to a XMPP LL connection
-		 * FIXME: We should inspect the flags of the contact list group interface
-		 */
-		g_object_unref (profile);
-		return FALSE;
-	}
-
-	g_object_unref (profile);
-	return TRUE;
+	return result;
 }
 
 static void
