@@ -24,7 +24,7 @@
 #include <string.h>
 #include <sys/stat.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
@@ -32,7 +32,6 @@
 #include <libmissioncontrol/mc-protocol.h>
 
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-debug.h>
 
 #include <libempathy/empathy-irc-network-manager.h>
 #include "empathy-ui-utils.h"
@@ -40,8 +39,6 @@
 
 #include "empathy-irc-network-dialog.h"
 
-#define DEBUG_DOMAIN "AccountWidgetIRC"
-
 typedef struct {
   EmpathyIrcNetwork *network;
 
