@@ -34,20 +34,38 @@
 #include <string.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <glade/glade.h>
+#include <canberra-gtk.h>
 
 #include <libmissioncontrol/mc-profile.h>
 
 #include "empathy-ui-utils.h"
 #include "empathy-images.h"
+#include "empathy-conf.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
+#include <libempathy/empathy-idle.h>
+
+void
+empathy_gtk_init (void)
+{
+	static gboolean initialized = FALSE;
+
+	if (initialized)
+		return;
+
+	empathy_init ();
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+					   PKGDATADIR G_DIR_SEPARATOR_S "icons");
+
+	initialized = TRUE;
+}
 
 struct SizeData {
 	gint     width;
@@ -1332,7 +1350,8 @@ fixup_url (const gchar *url)
 }
 
 void
-empathy_url_show (const char *url)
+empathy_url_show (GtkWidget *parent,
+		  const char *url)
 {
 	gchar  *real_url;
 	GError *error = NULL;
@@ -1342,10 +1361,9 @@ empathy_url_show (const char *url)
 		url = real_url;
 	}
 
-	/* FIXME: this does not work for multihead, we should use
-	 * GdkAppLaunchContext or gtk_show_url, see bug #514396.
-	 */
-	g_app_info_launch_default_for_uri (url, NULL, &error);
+	gtk_show_uri (gtk_widget_get_screen (parent), url,
+		      gtk_get_current_event_time (), &error);
+
 	if (error) {
 		GtkWidget *dialog;
 
@@ -1371,7 +1389,7 @@ link_button_hook (GtkLinkButton *button,
 		  const gchar *link,
 		  gpointer user_data)
 {
-	empathy_url_show (link);
+	empathy_url_show (GTK_WIDGET (button), link);
 }
 
 GtkWidget *
@@ -1401,54 +1419,6 @@ empathy_toggle_button_set_state_quietly (GtkWidget *widget,
 	g_signal_handlers_unblock_by_func (widget, callback, user_data);
 }
 
-GtkTextTag *
-empathy_text_buffer_tag_set (GtkTextBuffer *buffer,
-			     const gchar   *tag_name,
-			     const gchar   *first_property_name,
-			     ...)
-{
-	GtkTextTagTable *table;
-	GtkTextTag      *tag;
-
-	g_return_val_if_fail (GTK_IS_TEXT_BUFFER (buffer), NULL);
-	g_return_val_if_fail (tag_name != NULL, NULL);
-
-	table = gtk_text_buffer_get_tag_table (buffer);
-	tag = gtk_text_tag_table_lookup (table, tag_name);
-
-	if (!tag) {
-		tag = gtk_text_tag_new (tag_name);
-		gtk_text_tag_table_add (table, tag);
-		g_object_unref (tag);
-	} else {
-		/* Clear the old values so that we don't affect the new theme. */
-		g_object_set (tag,
-			      "background-set", FALSE,
-			      "foreground-set", FALSE,
-			      "invisible-set", FALSE,
-			      "justification-set", FALSE,
-			      "paragraph-background-set", FALSE,
-			      "pixels-above-lines-set", FALSE,
-			      "pixels-below-lines-set", FALSE,
-			      "rise-set", FALSE,
-			      "scale-set", FALSE,
-			      "size-set", FALSE,
-			      "style-set", FALSE,
-			      "weight-set", FALSE,
-			      NULL);
-	}
-
-	if (first_property_name) {
-		va_list list;
-
-		va_start (list, first_property_name);
-		g_object_set_valist (G_OBJECT (tag), first_property_name, list);
-		va_end (list);
-	}
-
-	return tag;
-}
-
 /* Sending files with the file chooser */
 
 static void
@@ -1522,3 +1492,97 @@ empathy_send_file_with_file_chooser (EmpathyContact *contact)
 
 	gtk_widget_show (widget);
 }
+
+typedef struct {
+	EmpathySound sound_id;
+	const char * event_ca_id;
+	const char * event_ca_description;
+	const char * gconf_key;
+} EmpathySoundEntry;
+
+/* NOTE: these entries MUST be in the same order of the EmpathySound enum */
+static EmpathySoundEntry sound_entries[LAST_EMPATHY_SOUND] = {
+	{ EMPATHY_SOUND_MESSAGE_INCOMING, "message-new-instant",
+	  N_("Received an instant message"), EMPATHY_PREFS_SOUNDS_INCOMING_MESSAGE } ,
+	{ EMPATHY_SOUND_MESSAGE_OUTGOING, "message-sent-instant",
+	  N_("Sent an instant message"), EMPATHY_PREFS_SOUNDS_OUTGOING_MESSAGE } ,
+	{ EMPATHY_SOUND_CONVERSATION_NEW, "message-new-instant",
+	  N_("Incoming chat request"), EMPATHY_PREFS_SOUNDS_NEW_CONVERSATION },
+	{ EMPATHY_SOUND_CONTACT_CONNECTED, "service-login",
+	  N_("Contact connected"), EMPATHY_PREFS_SOUNDS_CONTACT_LOGIN },
+	{ EMPATHY_SOUND_CONTACT_DISCONNECTED, "service-logout",
+	  N_("Contact disconnected"), EMPATHY_PREFS_SOUNDS_CONTACT_LOGOUT },
+	{ EMPATHY_SOUND_ACCOUNT_CONNECTED, "service-login",
+	  N_("Connected to server"), EMPATHY_PREFS_SOUNDS_SERVICE_LOGIN },
+	{ EMPATHY_SOUND_ACCOUNT_DISCONNECTED, "service-logout",
+	  N_("Disconnected from server"), EMPATHY_PREFS_SOUNDS_SERVICE_LOGOUT },
+	{ EMPATHY_SOUND_PHONE_INCOMING, "phone-incoming-call",
+	  N_("Incoming voice call"), NULL },
+	{ EMPATHY_SOUND_PHONE_OUTGOING, "phone-outgoing-calling",
+	  N_("Outgoing voice call"), NULL },
+	{ EMPATHY_SOUND_PHONE_HANGUP, "phone-hangup",
+	  N_("Voice call ended"), NULL },
+};
+
+static gboolean
+empathy_sound_pref_is_enabled (const char *key)
+{
+	EmpathyConf *conf;
+	McPresence presence;
+	gboolean res;
+	EmpathyIdle *idle;
+
+	conf = empathy_conf_get ();
+	res = FALSE;
+
+	empathy_conf_get_bool (conf, EMPATHY_PREFS_SOUNDS_ENABLED, &res);
+
+	if (!res) {
+		return FALSE;
+	}
+
+	idle = empathy_idle_new ();
+	presence = empathy_idle_get_state (idle);
+	g_object_unref (idle);
+
+	if (presence != MC_PRESENCE_AVAILABLE &&
+	    presence != MC_PRESENCE_UNSET) {
+		empathy_conf_get_bool (conf, EMPATHY_PREFS_SOUNDS_DISABLED_AWAY,
+				       &res);
+		if (res) {
+			return FALSE;
+		}
+	}
+
+	empathy_conf_get_bool (conf, key, &res);
+
+	return res;
+}
+
+void
+empathy_sound_play (GtkWidget *widget,
+		    EmpathySound sound_id)
+{
+	EmpathySoundEntry *entry;
+	gboolean should_play = TRUE;
+
+	g_return_if_fail (sound_id < LAST_EMPATHY_SOUND);
+
+	entry = &(sound_entries[sound_id]);
+	g_return_if_fail (entry->sound_id == sound_id);
+
+	if (entry->gconf_key != NULL) {
+		should_play = empathy_sound_pref_is_enabled (entry->gconf_key);
+	}
+
+	if (should_play) {
+		DEBUG ("Play sound \"%s\" (%s)",
+		       entry->event_ca_id,
+		       entry->event_ca_description);
+
+		ca_gtk_play_for_widget (widget, 0,
+					CA_PROP_EVENT_ID, entry->event_ca_id,
+					CA_PROP_EVENT_DESCRIPTION, gettext (entry->event_ca_description),
+					NULL);
+	}
+}
