@@ -44,8 +44,23 @@
 
 G_BEGIN_DECLS
 
+typedef enum {
+	EMPATHY_SOUND_MESSAGE_INCOMING,
+	EMPATHY_SOUND_MESSAGE_OUTGOING,
+	EMPATHY_SOUND_CONVERSATION_NEW,
+	EMPATHY_SOUND_CONTACT_CONNECTED,
+	EMPATHY_SOUND_CONTACT_DISCONNECTED,
+	EMPATHY_SOUND_ACCOUNT_CONNECTED,
+	EMPATHY_SOUND_ACCOUNT_DISCONNECTED,
+	EMPATHY_SOUND_PHONE_INCOMING,
+	EMPATHY_SOUND_PHONE_OUTGOING,
+	EMPATHY_SOUND_PHONE_HANGUP,
+	LAST_EMPATHY_SOUND
+} EmpathySound;
+
 #define G_STR_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
+void            empathy_gtk_init                        (void);
 /* Glade */
 void            empathy_glade_get_file_simple           (const gchar      *filename,
 							 const gchar      *root,
@@ -102,20 +117,21 @@ void        empathy_window_present                      (GtkWindow        *windo
 void        empathy_window_iconify                      (GtkWindow        *window,
 							 GtkStatusIcon    *status_icon);
 GtkWindow * empathy_get_toplevel_window                 (GtkWidget        *widget);
-void        empathy_url_show                            (const char       *url);
+void        empathy_url_show                            (GtkWidget        *parent,
+							 const char       *url);
 void        empathy_toggle_button_set_state_quietly     (GtkWidget        *widget,
 							 GCallback         callback,
 							 gpointer          user_data,
 							 gboolean          active);
 GtkWidget * empathy_link_button_new                     (const gchar      *url,
 							 const gchar      *title);
-GtkTextTag *empathy_text_buffer_tag_set                 (GtkTextBuffer *buffer,
-							 const gchar   *tag_name,
-							 const gchar   *first_property_name,
-							 ...);
 
 void        empathy_send_file_with_file_chooser         (EmpathyContact   *contact);
 
+/* Sounds */
+void        empathy_sound_play                          (GtkWidget        *widget,
+							 EmpathySound      sound_id);
+
 G_END_DECLS
 
 #endif /*  __EMPATHY_UI_UTILS_H__ */
