@@ -53,7 +53,7 @@ struct _EmpathyChatroomManagerClass {
 };
 
 GType                  empathy_chatroom_manager_get_type      (void) G_GNUC_CONST;
-EmpathyChatroomManager *empathy_chatroom_manager_new           (void);
+EmpathyChatroomManager *empathy_chatroom_manager_new           (const gchar *file);
 gboolean               empathy_chatroom_manager_add           (EmpathyChatroomManager *manager,
 							      EmpathyChatroom        *chatroom);
 void                   empathy_chatroom_manager_remove        (EmpathyChatroomManager *manager,
@@ -65,7 +65,6 @@ GList *                empathy_chatroom_manager_get_chatrooms (EmpathyChatroomMa
 							      McAccount             *account);
 guint                  empathy_chatroom_manager_get_count     (EmpathyChatroomManager *manager,
 							      McAccount             *account);
-void                   empathy_chatroom_manager_store         (EmpathyChatroomManager *manager);
 
 G_END_DECLS
 
