@@ -23,7 +23,7 @@
 
 #include <string.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <dbus/dbus-glib.h>
 
 #include <telepathy-glib/dbus.h>
@@ -402,11 +402,22 @@ empathy_idle_init (EmpathyIdle *idle)
 	idle->priv = priv;
 	priv->is_idle = FALSE;
 	priv->mc = empathy_mission_control_new ();
-	priv->state = mission_control_get_presence_actual (priv->mc, NULL);
-	priv->status = mission_control_get_presence_message_actual (priv->mc, NULL);
-	if (G_STR_EMPTY (priv->status)) {
+	priv->state = mission_control_get_presence_actual (priv->mc, &error);
+	if (error) {
+		DEBUG ("Error getting actual presence: %s", error->message);
+
+		priv->state = MC_PRESENCE_UNSET;
+		g_clear_error (&error);
+	}
+	priv->status = mission_control_get_presence_message_actual (priv->mc, &error);
+	if (error || G_STR_EMPTY (priv->status)) {
 		g_free (priv->status);
 		priv->status = NULL;
+
+		if (error) {
+			DEBUG ("Error getting actual presence message: %s", error->message);
+			g_clear_error (&error);
+		}
 	}
 
 	dbus_g_proxy_connect_signal (DBUS_G_PROXY (priv->mc),
