@@ -27,6 +27,7 @@
 #include <string.h>
 
 #include "empathy-message.h"
+#include "empathy-utils.h"
 #include "empathy-enum-types.h"
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyMessage)
@@ -383,26 +384,6 @@ empathy_message_set_timestamp (EmpathyMessage *message,
 	g_object_notify (G_OBJECT (message), "timestamp");
 }
 
-GDate *
-empathy_message_get_date_and_time (EmpathyMessage *message, time_t *timestamp)
-{
-	GDate *date;
-
-	*timestamp = 0;
-	if (message) {
-		*timestamp = empathy_message_get_timestamp (message);
-	}
-
-	if (timestamp <= 0) {
-		*timestamp = empathy_time_get_current ();
-	}
-
-	date = g_date_new ();
-	g_date_set_time_t (date, *timestamp);
-
-	return date;
-}
-
 #define IS_SEPARATOR(ch) (ch == ' ' || ch == ',' || ch == '.' || ch == ':')
 gboolean
 empathy_message_should_highlight (EmpathyMessage *message)
