@@ -32,7 +32,7 @@
 
 G_BEGIN_DECLS
 
-#define EMPATHY_TYPE_MESSAGE         (empathy_message_get_gtype ())
+#define EMPATHY_TYPE_MESSAGE         (empathy_message_get_type ())
 #define EMPATHY_MESSAGE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), EMPATHY_TYPE_MESSAGE, EmpathyMessage))
 #define EMPATHY_MESSAGE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), EMPATHY_TYPE_MESSAGE, EmpathyMessageClass))
 #define EMPATHY_IS_MESSAGE(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), EMPATHY_TYPE_MESSAGE))
@@ -44,42 +44,33 @@ typedef struct _EmpathyMessageClass EmpathyMessageClass;
 
 struct _EmpathyMessage {
 	GObject parent;
+	gpointer priv;
 };
 
 struct _EmpathyMessageClass {
 	GObjectClass parent_class;
 };
 
-typedef enum {
-	EMPATHY_MESSAGE_TYPE_NORMAL,
-	EMPATHY_MESSAGE_TYPE_ACTION,
-	EMPATHY_MESSAGE_TYPE_NOTICE,
-	EMPATHY_MESSAGE_TYPE_AUTO_REPLY,
-	EMPATHY_MESSAGE_TYPE_LAST
-} EmpathyMessageType;
-
-GType              empathy_message_get_gtype         (void) G_GNUC_CONST;
-EmpathyMessage *   empathy_message_new               (const gchar        *body);
-EmpathyMessageType empathy_message_get_type          (EmpathyMessage     *message);
-void               empathy_message_set_type          (EmpathyMessage     *message,
-						      EmpathyMessageType  type);
-EmpathyContact *   empathy_message_get_sender        (EmpathyMessage     *message);
-void               empathy_message_set_sender        (EmpathyMessage     *message,
-						      EmpathyContact     *contact);
-EmpathyContact *   empathy_message_get_receiver      (EmpathyMessage     *message);
-void               empathy_message_set_receiver      (EmpathyMessage     *message,
-						      EmpathyContact     *contact);
-const gchar *      empathy_message_get_body          (EmpathyMessage     *message);
-void               empathy_message_set_body          (EmpathyMessage     *message,
-						      const gchar        *body);
-time_t             empathy_message_get_timestamp     (EmpathyMessage     *message);
-void               empathy_message_set_timestamp     (EmpathyMessage     *message,
-						      time_t              timestamp);
-GDate *            empathy_message_get_date_and_time (EmpathyMessage     *message,
-						      time_t             *timestamp);
-gboolean           empathy_message_should_highlight  (EmpathyMessage     *message);
-EmpathyMessageType empathy_message_type_from_str     (const gchar        *type_str);
-const gchar *      empathy_message_type_to_str       (EmpathyMessageType  type);
+GType                    empathy_message_get_type          (void) G_GNUC_CONST;
+EmpathyMessage *         empathy_message_new               (const gchar              *body);
+TpChannelTextMessageType empathy_message_get_tptype        (EmpathyMessage           *message);
+void                     empathy_message_set_tptype        (EmpathyMessage           *message,
+							    TpChannelTextMessageType  type);
+EmpathyContact *         empathy_message_get_sender        (EmpathyMessage           *message);
+void                     empathy_message_set_sender        (EmpathyMessage           *message,
+							    EmpathyContact           *contact);
+EmpathyContact *         empathy_message_get_receiver      (EmpathyMessage           *message);
+void                     empathy_message_set_receiver      (EmpathyMessage           *message,
+							    EmpathyContact           *contact);
+const gchar *            empathy_message_get_body          (EmpathyMessage           *message);
+void                     empathy_message_set_body          (EmpathyMessage           *message,
+							    const gchar              *body);
+time_t                   empathy_message_get_timestamp     (EmpathyMessage           *message);
+void                     empathy_message_set_timestamp     (EmpathyMessage           *message,
+							    time_t                    timestamp);
+gboolean                 empathy_message_should_highlight  (EmpathyMessage           *message);
+TpChannelTextMessageType empathy_message_type_from_str     (const gchar              *type_str);
+const gchar *            empathy_message_type_to_str       (TpChannelTextMessageType  type);
 
 G_END_DECLS
 
