@@ -25,24 +25,35 @@
 
 #include <telepathy-glib/util.h>
 #include <telepathy-glib/connection.h>
+#include <telepathy-glib/gtypes.h>
 #include <libmissioncontrol/mission-control.h>
 
+#include <extensions/extensions.h>
+
 #include "empathy-tp-contact-factory.h"
 #include "empathy-utils.h"
+#include "empathy-account-manager.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_TP | EMPATHY_DEBUG_CONTACT
 #include "empathy-debug.h"
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyTpContactFactory)
 typedef struct {
-	MissionControl *mc;
+	EmpathyAccountManager *account_manager;
 	McAccount      *account;
 	TpConnection   *connection;
 	gboolean        ready;
 
 	GList          *contacts;
 	EmpathyContact *user;
-	gpointer        token;
+
+	gchar         **avatar_mime_types;
+	guint           avatar_min_width;
+	guint           avatar_min_height;
+	guint           avatar_max_width;
+	guint           avatar_max_height;
+	guint           avatar_max_size;
+  gboolean        can_request_ft;
 } EmpathyTpContactFactoryPriv;
 
 G_DEFINE_TYPE (EmpathyTpContactFactory, empathy_tp_contact_factory, G_TYPE_OBJECT);
@@ -50,7 +61,14 @@ G_DEFINE_TYPE (EmpathyTpContactFactory, empathy_tp_contact_factory, G_TYPE_OBJEC
 enum {
 	PROP_0,
 	PROP_ACCOUNT,
-	PROP_READY
+	PROP_READY,
+
+	PROP_MIME_TYPES,
+	PROP_MIN_WIDTH,
+	PROP_MIN_HEIGHT,
+	PROP_MAX_WIDTH,
+	PROP_MAX_HEIGHT,
+	PROP_MAX_SIZE
 };
 
 static EmpathyContact *
@@ -323,7 +341,6 @@ tp_contact_factory_avatar_retrieved_cb (TpConnection *connection,
 					GObject      *tp_factory)
 {
 	EmpathyContact *contact;
-	EmpathyAvatar  *avatar;
 
 	contact = tp_contact_factory_find_by_handle (EMPATHY_TP_CONTACT_FACTORY (tp_factory),
 						     handle);
@@ -335,13 +352,11 @@ tp_contact_factory_avatar_retrieved_cb (TpConnection *connection,
 		empathy_contact_get_id (contact),
 		handle);
 
-	avatar = empathy_avatar_new (avatar_data->data,
-				     avatar_data->len,
-				     mime_type,
-				     token);
-
-	empathy_contact_set_avatar (contact, avatar);
-	empathy_avatar_unref (avatar);
+	empathy_contact_load_avatar_data (contact,
+					  avatar_data->data,
+					  avatar_data->len,
+					  mime_type,
+					  token);
 }
 
 static void
@@ -381,11 +396,8 @@ tp_contact_factory_avatar_maybe_update (EmpathyTpContactFactory *tp_factory,
 	}
 
 	/* The avatar changed, search the new one in the cache */
-	avatar = empathy_avatar_new_from_cache (token);
-	if (avatar) {
+	if (empathy_contact_load_avatar_cache (contact, token)) {
 		/* Got from cache, use it */
-		empathy_contact_set_avatar (contact, avatar);
-		empathy_avatar_unref (avatar);
 		return TRUE;
 	}
 
@@ -717,13 +729,8 @@ tp_contact_factory_connection_invalidated_cb (EmpathyTpContactFactory *tp_factor
 			tp_factory);
 }
 
-
 static void
-tp_contact_factory_got_self_handle_cb (TpConnection *proxy,
-				       guint         handle,
-				       const GError *error,
-				       gpointer      user_data,
-				       GObject      *tp_factory)
+tp_contact_factory_ready (EmpathyTpContactFactory *tp_factory)
 {
 	EmpathyTpContactFactoryPriv *priv = GET_PRIV (tp_factory);
 	GList                       *l;
@@ -732,16 +739,10 @@ tp_contact_factory_got_self_handle_cb (TpConnection *proxy,
 	GList                       *handle_needed_contacts = NULL;
 	GList                       *id_needed_contacts = NULL;
 
-	if (error) {
-		DEBUG ("Failed to get self handles: %s", error->message);
-		return;
-	}
-
 	DEBUG ("Connection ready");
 
-	empathy_contact_set_handle (priv->user, handle);
 	priv->ready = TRUE;
-	g_object_notify (tp_factory, "ready");
+	g_object_notify (G_OBJECT (tp_factory), "ready");
 
 	/* Connect signals */
 	tp_cli_connection_interface_aliasing_connect_to_aliases_changed (priv->connection,
@@ -804,8 +805,6 @@ tp_contact_factory_got_self_handle_cb (TpConnection *proxy,
 						handle_needed_contacts, tp_contact_factory_list_free,
 						G_OBJECT (tp_factory));
 
-	tp_contact_factory_request_everything ((EmpathyTpContactFactory*) tp_factory,
-					       id_needed);
 	tp_cli_connection_call_inspect_handles (priv->connection,
 						-1,
 						TP_HANDLE_TYPE_CONTACT,
@@ -814,10 +813,141 @@ tp_contact_factory_got_self_handle_cb (TpConnection *proxy,
 						id_needed_contacts, tp_contact_factory_list_free,
 						G_OBJECT (tp_factory));
 
+	tp_contact_factory_request_everything ((EmpathyTpContactFactory*) tp_factory,
+					       id_needed);
+
 	g_array_free (handle_needed, TRUE);
 	g_array_free (id_needed, TRUE);
 }
 
+static void
+get_requestable_channel_classes_cb (TpProxy *connection,
+				    const GValue *value,
+				    const GError *error,
+				    gpointer user_data,
+				    GObject *weak_object)
+{
+	EmpathyTpContactFactory     *self = EMPATHY_TP_CONTACT_FACTORY (weak_object);
+	EmpathyTpContactFactoryPriv *priv = GET_PRIV (self);
+	GPtrArray                   *classes;
+	guint                        i;
+
+	if (error != NULL) {
+		DEBUG ("Error: %s", error->message);
+		tp_contact_factory_ready (self);
+		return;
+	}
+
+	classes = g_value_get_boxed (value);
+	for (i = 0; i < classes->len; i++) {
+		GValue class = {0,};
+		GValue *chan_type, *handle_type;
+		GHashTable *fixed_prop;
+		GList *l;
+
+		g_value_init (&class, TP_STRUCT_TYPE_REQUESTABLE_CHANNEL_CLASS);
+		g_value_set_static_boxed (&class, g_ptr_array_index (classes, i));
+
+		dbus_g_type_struct_get (&class,
+					0, &fixed_prop,
+					G_MAXUINT);
+
+		chan_type = g_hash_table_lookup (fixed_prop,
+			TP_IFACE_CHANNEL ".ChannelType");
+		if (chan_type == NULL ||
+		    tp_strdiff (g_value_get_string (chan_type),
+		    		EMP_IFACE_CHANNEL_TYPE_FILE_TRANSFER)) {
+			continue;
+		}
+
+		handle_type = g_hash_table_lookup (fixed_prop,
+			TP_IFACE_CHANNEL ".TargetHandleType");
+		if (handle_type == NULL ||
+		    g_value_get_uint (handle_type) != TP_HANDLE_TYPE_CONTACT) {
+			continue;
+		}
+
+		/* We can request file transfer channel to contacts. */
+		priv->can_request_ft = TRUE;
+
+		/* Update the capabilities of all contacts */
+		for (l = priv->contacts; l != NULL; l = g_list_next (l)) {
+			EmpathyContact *contact = l->data;
+			EmpathyCapabilities caps;
+
+			caps = empathy_contact_get_capabilities (contact);
+			empathy_contact_set_capabilities (contact, caps |
+				EMPATHY_CAPABILITIES_FT);
+		}
+
+		break;
+	}
+
+	tp_contact_factory_ready (self);
+}
+
+static void
+tp_contact_factory_got_avatar_requirements_cb (TpConnection *proxy,
+					       const gchar **mime_types,
+					       guint         min_width,
+					       guint         min_height,
+					       guint         max_width,
+					       guint         max_height,
+					       guint         max_size,
+					       const GError *error,
+					       gpointer      user_data,
+					       GObject      *tp_factory)
+{
+	EmpathyTpContactFactoryPriv *priv = GET_PRIV (tp_factory);
+
+	if (error) {
+		DEBUG ("Failed to get avatar requirements: %s", error->message);
+		/* We'll just leave avatar_mime_types as NULL; the
+		 * avatar-setting code can use this as a signal that you can't
+		 * set avatars.
+		 */
+	} else {
+		priv->avatar_mime_types = g_strdupv ((gchar **) mime_types);
+		priv->avatar_min_width = min_width;
+		priv->avatar_min_height = min_height;
+		priv->avatar_max_width = max_width;
+		priv->avatar_max_height = max_height;
+		priv->avatar_max_size = max_size;
+	}
+
+	/* Can we request file transfer channels? */
+	tp_cli_dbus_properties_call_get (priv->connection, -1,
+		TP_IFACE_CONNECTION_INTERFACE_REQUESTS,
+		"RequestableChannelClasses",
+		get_requestable_channel_classes_cb, NULL, NULL,
+		G_OBJECT (tp_factory));
+}
+
+static void
+tp_contact_factory_got_self_handle_cb (TpConnection *proxy,
+				       guint         handle,
+				       const GError *error,
+				       gpointer      user_data,
+				       GObject      *tp_factory)
+{
+	EmpathyTpContactFactoryPriv *priv = GET_PRIV (tp_factory);
+
+	if (error) {
+		DEBUG ("Failed to get self handles: %s", error->message);
+		return;
+	}
+
+	empathy_contact_set_handle (priv->user, handle);
+
+	/* Get avatar requirements for this connection */
+	tp_cli_connection_interface_avatars_call_get_avatar_requirements (
+		priv->connection,
+		-1,
+		tp_contact_factory_got_avatar_requirements_cb,
+		NULL, NULL,
+		tp_factory);
+}
+
 static void
 tp_contact_factory_connection_ready_cb (EmpathyTpContactFactory *tp_factory)
 {
@@ -836,13 +966,15 @@ tp_contact_factory_status_updated (EmpathyTpContactFactory *tp_factory)
 {
 	EmpathyTpContactFactoryPriv *priv = GET_PRIV (tp_factory);
 	gboolean                     connection_ready;
+	MissionControl              *mc;
 
 	if (priv->connection) {
 		/* We already have our connection object */
 		return;
 	}
 
-	priv->connection = mission_control_get_tpconnection (priv->mc, priv->account, NULL);
+	mc = empathy_mission_control_new ();
+	priv->connection = mission_control_get_tpconnection (mc, priv->account, NULL);
 	if (!priv->connection) {
 		return;
 	}
@@ -860,24 +992,23 @@ tp_contact_factory_status_updated (EmpathyTpContactFactory *tp_factory)
 					  G_CALLBACK (tp_contact_factory_connection_ready_cb),
 					  tp_factory);
 	}
+
+	g_object_unref (mc);
 }
 
 static void
-tp_contact_factory_status_changed_cb (MissionControl           *mc,
-				      TpConnectionStatus        status,
-				      McPresence                presence,
-				      TpConnectionStatusReason  reason,
-				      const gchar              *unique_name,
-				      EmpathyTpContactFactory  *tp_factory)
+tp_contact_factory_account_connection_cb (EmpathyAccountManager *account_manager,
+					  McAccount *account,
+					  TpConnectionStatusReason reason,
+					  TpConnectionStatus current,
+					  TpConnectionStatus previous,
+					  EmpathyTpContactFactory  *tp_factory)
 {
 	EmpathyTpContactFactoryPriv *priv = GET_PRIV (tp_factory);
-	McAccount                   *account;
 
-	account = mc_account_lookup (unique_name);
 	if (account && empathy_account_equal (account, priv->account)) {
 		tp_contact_factory_status_updated (tp_factory);
 	}
-	g_object_unref (account);
 }
 
 static void
@@ -917,6 +1048,27 @@ empathy_tp_contact_factory_get_user (EmpathyTpContactFactory *tp_factory)
 	return g_object_ref (priv->user);
 }
 
+static void
+contact_created (EmpathyTpContactFactory *self,
+                 EmpathyContact *contact)
+{
+  EmpathyTpContactFactoryPriv *priv = GET_PRIV (self);
+
+  if (priv->can_request_ft)
+    {
+      /* Set the FT capability */
+      /* FIXME: We should use the futur ContactCapabilities interface */
+      EmpathyCapabilities caps;
+
+      caps = empathy_contact_get_capabilities (contact);
+      caps |= EMPATHY_CAPABILITIES_FT;
+
+      empathy_contact_set_capabilities (contact, caps);
+    }
+
+  tp_contact_factory_add_contact (self, contact);
+}
+
 EmpathyContact *
 empathy_tp_contact_factory_get_from_id (EmpathyTpContactFactory *tp_factory,
 					const gchar             *id)
@@ -938,7 +1090,7 @@ empathy_tp_contact_factory_get_from_id (EmpathyTpContactFactory *tp_factory,
 				"account", priv->account,
 				"id", id,
 				NULL);
-	tp_contact_factory_add_contact (tp_factory, contact);
+	contact_created (tp_factory, contact);
 
 	if (priv->ready) {
 		const gchar *contact_ids[] = {id, NULL};
@@ -1027,7 +1179,7 @@ empathy_tp_contact_factory_get_from_handles (EmpathyTpContactFactory *tp_factory
 					"account", priv->account,
 					"handle", handle,
 					NULL);
-		tp_contact_factory_add_contact (tp_factory, contact);
+		contact_created (tp_factory, contact);
 		contacts = g_list_prepend (contacts, contact);
 		new_contacts = g_list_prepend (new_contacts, g_object_ref (contact));
 	}
@@ -1056,6 +1208,8 @@ empathy_tp_contact_factory_get_from_handles (EmpathyTpContactFactory *tp_factory
 		tp_contact_factory_request_everything (tp_factory, new_handles);
 	}
 
+	g_array_free (new_handles, TRUE);
+
 	return contacts;
 }
 
@@ -1163,6 +1317,24 @@ tp_contact_factory_get_property (GObject    *object,
 	case PROP_READY:
 		g_value_set_boolean (value, priv->ready);
 		break;
+	case PROP_MIME_TYPES:
+		g_value_set_boxed (value, priv->avatar_mime_types);
+		break;
+	case PROP_MIN_WIDTH:
+		g_value_set_uint (value, priv->avatar_min_width);
+		break;
+	case PROP_MIN_HEIGHT:
+		g_value_set_uint (value, priv->avatar_min_height);
+		break;
+	case PROP_MAX_WIDTH:
+		g_value_set_uint (value, priv->avatar_max_width);
+		break;
+	case PROP_MAX_HEIGHT:
+		g_value_set_uint (value, priv->avatar_max_height);
+		break;
+	case PROP_MAX_SIZE:
+		g_value_set_uint (value, priv->avatar_max_size);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -1196,7 +1368,9 @@ tp_contact_factory_finalize (GObject *object)
 	DEBUG ("Finalized: %p (%s)", object,
 		mc_account_get_normalized_name (priv->account));
 
-	empathy_disconnect_account_status_changed (priv->token);
+	g_signal_handlers_disconnect_by_func (priv->account_manager,
+					      tp_contact_factory_account_connection_cb,
+					      object);
 
 	for (l = priv->contacts; l; l = l->next) {
 		g_object_weak_unref (G_OBJECT (l->data),
@@ -1205,7 +1379,7 @@ tp_contact_factory_finalize (GObject *object)
 	}
 
 	g_list_free (priv->contacts);
-	g_object_unref (priv->mc);
+	g_object_unref (priv->account_manager);
 	g_object_unref (priv->account);
 	g_object_unref (priv->user);
 
@@ -1216,6 +1390,8 @@ tp_contact_factory_finalize (GObject *object)
 		g_object_unref (priv->connection);
 	}
 
+	g_strfreev (priv->avatar_mime_types);
+
 	G_OBJECT_CLASS (empathy_tp_contact_factory_parent_class)->finalize (object);
 }
 
@@ -1256,14 +1432,85 @@ empathy_tp_contact_factory_class_init (EmpathyTpContactFactoryClass *klass)
 							      "The account associated with the factory",
 							      MC_TYPE_ACCOUNT,
 							      G_PARAM_READWRITE |
-							      G_PARAM_CONSTRUCT_ONLY));
+							      G_PARAM_CONSTRUCT_ONLY |
+							      G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 					 PROP_READY,
 					 g_param_spec_boolean ("ready",
-							       "Wheter the factor is ready",
-							       "Is the factory ready",
+							       "Whether the factory is ready",
+							       "TRUE once the factory is ready to be used",
 							       FALSE,
-							       G_PARAM_READABLE));
+							       G_PARAM_READABLE |
+							       G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (object_class,
+					 PROP_MIME_TYPES,
+					 g_param_spec_boxed ("avatar-mime-types",
+							     "Supported MIME types for avatars",
+							     "Types of images that may be set as "
+							     "avatars on this connection.  Only valid "
+							     "once 'ready' becomes TRUE.",
+							     G_TYPE_STRV,
+							     G_PARAM_READABLE |
+							     G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (object_class,
+					 PROP_MIN_WIDTH,
+					 g_param_spec_uint ("avatar-min-width",
+							    "Minimum width for avatars",
+							    "Minimum width of avatar that may be set. "
+							    "Only valid once 'ready' becomes TRUE.",
+							    0,
+							    G_MAXUINT,
+							    0,
+							    G_PARAM_READABLE |
+							    G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (object_class,
+					 PROP_MIN_HEIGHT,
+					 g_param_spec_uint ("avatar-min-height",
+							    "Minimum height for avatars",
+							    "Minimum height of avatar that may be set. "
+							    "Only valid once 'ready' becomes TRUE.",
+							    0,
+							    G_MAXUINT,
+							    0,
+							    G_PARAM_READABLE |
+							    G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (object_class,
+					 PROP_MAX_WIDTH,
+					 g_param_spec_uint ("avatar-max-width",
+							    "Maximum width for avatars",
+							    "Maximum width of avatar that may be set "
+							    "or 0 if there is no maximum. "
+							    "Only valid once 'ready' becomes TRUE.",
+							    0,
+							    G_MAXUINT,
+							    0,
+							    G_PARAM_READABLE |
+							    G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (object_class,
+					 PROP_MAX_HEIGHT,
+					 g_param_spec_uint ("avatar-max-height",
+							    "Maximum height for avatars",
+							    "Maximum height of avatar that may be set "
+							    "or 0 if there is no maximum. "
+							    "Only valid once 'ready' becomes TRUE.",
+							    0,
+							    G_MAXUINT,
+							    0,
+							    G_PARAM_READABLE |
+							    G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (object_class,
+					 PROP_MAX_SIZE,
+					 g_param_spec_uint ("avatar-max-size",
+							    "Maximum size for avatars in bytes",
+							    "Maximum file size of avatar that may be "
+							    "set or 0 if there is no maximum. "
+							    "Only valid once 'ready' becomes TRUE.",
+							    0,
+							    G_MAXUINT,
+							    0,
+							    G_PARAM_READABLE |
+							    G_PARAM_STATIC_STRINGS));
+
 
 	g_type_class_add_private (object_class, sizeof (EmpathyTpContactFactoryPriv));
 }
@@ -1275,10 +1522,13 @@ empathy_tp_contact_factory_init (EmpathyTpContactFactory *tp_factory)
 		EMPATHY_TYPE_TP_CONTACT_FACTORY, EmpathyTpContactFactoryPriv);
 
 	tp_factory->priv = priv;
-	priv->mc = empathy_mission_control_new ();
-	priv->token = empathy_connect_to_account_status_changed (priv->mc,
-						   G_CALLBACK (tp_contact_factory_status_changed_cb),
-						   tp_factory, NULL);
+	priv->account_manager = empathy_account_manager_dup_singleton ();
+
+	g_signal_connect (priv->account_manager, "account-connection-changed",
+			  G_CALLBACK (tp_contact_factory_account_connection_cb),
+			  tp_factory);
+
+	priv->can_request_ft = FALSE;
 }
 
 EmpathyTpContactFactory *
