@@ -26,11 +26,11 @@
 
 #include <gtk/gtk.h>
 
-#include <libempathy/empathy-tp-call.h>
+#include <telepathy-glib/channel.h>
 
 G_BEGIN_DECLS
 
-GtkWidget *empathy_call_window_new (EmpathyTpCall *call);
+GtkWidget *empathy_call_window_new (TpChannel *channel);
 
 G_END_DECLS
 
